from ocp_resources.resource import Resource


class VirtualMachineClusterInstancetype(Resource):
    api_group = Resource.ApiGroup.INSTANCETYPE_KUBEVIRT_IO
